# skan: skeleton analysis in Python
Python module to analyse skeleton (thin object) images

[![Build Status](https://travis-ci.org/jni/skan.svg?branch=master)](https://travis-ci.org/jni/skan)
[![Coverage Status](https://coveralls.io/repos/github/jni/skan/badge.svg?branch=master)](https://coveralls.io/github/jni/skan?branch=master)

See the documentation at [https://jni.github.io/skan](https://jni.github.io/skan).
